@@ -1413,7 +1413,7 @@ def test_correct_url_used_for_s3():
     yield t.case(
         region='fips-us-gov-west-1', bucket='bucket', key='key',
         signature_version='s3',
-        expected_url='https://bucket.s3-fips-us-gov-west-1.amazonaws.com/key')
+        expected_url='https://bucket.s3-fips.us-gov-west-1.amazonaws.com/key')
 
 
     # Test path style addressing.
